//----------------------------------------------------------------------------
//  Description:  This file contains definitions specific to the DAC161P997.
//  All the DAC161P997 registers are defined as well as some common masks
//  for these registers.
//
//  MSP430/DAC161P997 Interface Code Library
//
//   Vishy Natarajan
//   Texas Instruments Inc.
//   January 2012
//   Built with CCE Version: 4.2 and IAR Embedded Workbench Version:  5.3x
//------------------------------------------------------------------------------
// Change Log:
//------------------------------------------------------------------------------
// Version:  1.00
// Comments: Initial Release Version
//------------------------------------------------------------------------------
#ifndef HEADER_FILE_TI_DAC161P997_H

#define HEADER_FILE_TI_DAC161P997_H
/************************************************************
* TI DAC161P997 REGISTER SET ADDRESSES
************************************************************/

#define TI_DAC161P997_LCK_REG                            (0x0000)              // Lock Register 
#define TI_DAC161P997_CONFIG1_REG                        (0x0100)              // Configuration Register CONFIG1
#define TI_DAC161P997_CONFIG2_REG                        (0x0200)              // Configuration Register CONFIG2           
#define TI_DAC161P997_CONFIG3_REG                        (0x0300)              // Configuration Register CONFIG3
#define TI_DAC161P997_ERR_LOW_REG                        (0x0400)              // Error Low Register
#define TI_DAC161P997_ERR_HIGH_REG                       (0x0500)              // Error High Register

// TI DAC161P997 Register Bits
#define LCK_REG_UNLOCK                                   (0x0095)
#define LCK_REG_LOCK                                     (0x00AA)              // any value other than 0x95 
#define CONFIG1_REG_RST                                  (0x0001)
#define CONFIG1_REG_NOP                                  (0*0x08u)
#define CONFIG1_REG_SET_ERR                              (1*0x08u)
#define CONFIG1_REG_CLEAR_ERR                            (2*0x08u)
#define CONFIG1_REG_NOP3                                 (3*0x08u)
#define CONFIG2_REG_LOOP                                 (0x0001)
#define CONFIG2_REG_CHANNEL                              (0x0002)
#define CONFIG2_REG_PARITY                               (0x0004)
#define CONFIG2_REG_FRAME                                (0x0008)
#define CONFIG2_REG_ACK_EN                               (0x0010)
#define CONFIG3_REG_RX_ERR_CNT_16                        (0x000F)
#define CONFIG3_REG_RX_ERR_CNT_8                         (0x0007)
#define CONFIG3_REG_RX_ERR_CNT_1                         (0x0000)

// Useful definitions

// Valid Symbols
#define ZERO_SYM                                         (0x00)
#define ONE_SYM                                          (0x01)
#define IDLE_SYM                                         (0x02)
#define STATIC_LOW_SYM                                   (0x03)

// Baud Rate : Choose between 300 to 19200 (symbols per sec)
#define BAUD_RATE                                        (8000)

// CPU Clock in Hertz (assumed to be the same as peripheral clock)
// If CPU clock and peripheral clock are different, use CPU_CLK for symbol period
// if BITBANG is used to send symbols. If TIMER_A0 or TIMER_B0 is used, use peripheral 
// clock
#define CPU_CLK                                          (8000000)

// Symbol Periods
#define DUTY_CYCLE_100                                   (CPU_CLK/BAUD_RATE)
#define DUTY_CYCLE_75                                    (DUTY_CYCLE_100 * 0.75)
#define DUTY_CYCLE_50                                    (DUTY_CYCLE_100 * 0.50)
#define DUTY_CYCLE_25                                    (DUTY_CYCLE_100 * 0.25)

// Tags
#define DACCODE_WRITE                                    (0x00)
#define CONFIG_WRITE                                     (0x01)

// DAC Codes for different currents
#define DACCODE_4mA                                      (0x2AAA)
#define DACCODE_12mA                                     (0x8000)

// Error Codes
#define DAC_ACK_FAIL                                     (0x01)
#define DAC_ACK_PASS                                     (0x00)
#define ACK_ERR_THRESHOLD                                (0x4)

 

#endif                                                                         // HEADER_FILE_DAC161P997_H
