//******************************************************************************
//  Description:  This file contains MSP430 pin definitions to interface to 
//                DAC161P997 Singe Wire Interface (SWIF)
//
//                MSP430F5528
//             -----------------
//         /|\|              XIN|-
//          | |                 |  32kHz
//          --|RST          XOUT|-
//            |                 |
//            |       P2.0/TA1.1|--> PRI_TX
//            |       P2.1/TA1.2|--> PRI_TX_EN_N 
//            |       P1.7/TA1.0|<-- PRI_RX 
//            |                 | 
//            |                 | 
//            |                 | 
//
//  MSP430/DAC161P997 Interface Code Library
//
//   Vishy Natarajan
//   Texas Instruments Inc.
//   October 2011
//   Built with CCE Version: 4.2 and IAR Embedded Workbench Version:  5.3x
//******************************************************************************
// Change Log:
//******************************************************************************
// Version:  1.00
// Comments: Initial Release Version
//******************************************************************************
#ifndef HEADER_TI_DAC161P997_MSP430_H

#define HEADER_FILE_TI_DAC161P997_MSP430_H

#include "msp430.h"

//******************************************************************************
// DAC161P997 SWIF Pins: PRI_TX, PRI_TX_EN_N, PRI_RX
// MSP430 GPIO Port P2 pins P2.0 and P2.1 connected to PRI_TX and PRI_TX_EN_N
// MSP430 GPIO Port P1 pin P1.7 connected to PRI_RX
//******************************************************************************

#define TI_DAC161P997_SWIF_PRITX_PxSEL          P2SEL
#define TI_DAC161P997_SWIF_PRITX_PxDIR          P2DIR        
#define TI_DAC161P997_SWIF_PRITX_PxOUT          P2OUT        
#define TI_DAC161P997_SWIF_PRITX_PIN            BIT0

#define TI_DAC161P997_SWIF_PRITXENN_PxSEL       P2SEL
#define TI_DAC161P997_SWIF_PRITXENN_PxDIR       P2DIR        
#define TI_DAC161P997_SWIF_PRITXENN_PxOUT       P2OUT        
#define TI_DAC161P997_SWIF_PRITXENN_PIN         BIT1

#define TI_DAC161P997_SWIF_PRIRX_PxSEL          P1SEL
#define TI_DAC161P997_SWIF_PRIRX_PxDIR          P1DIR        
#define TI_DAC161P997_SWIF_PRIRX_PxIN           P1IN
#define TI_DAC161P997_SWIF_PRIRX_PIN            BIT7

 
//******************************************************************************
// These constants are used to identify the chosen MSP430 peripheral to implement 
// the DAC161P997 SWIF port send symbol function TI_DAC161P997_SWIFSendSymbol.
//******************************************************************************
#define TI_DAC161P997_SER_INTF_NULL           0
#define TI_DAC161P997_SER_INTF_TIMER_A0_5xx   1
#define TI_DAC161P997_SER_INTF_TIMER_B0_5xx   2
#define TI_DAC161P997_SER_INTF_BITBANG        3
 
#endif                                                                         // HEADER_FILE_TI_DAC161P997_MSP430_H
